/*********************************************************
This is a library for the MPR121 12-channel Capacitive touch sensor

Designed specifically to work with the MPR121 Breakout in the Adafruit shop 
  ----> https://www.adafruit.com/products/

These sensors use I2C communicate, at least 2 pins are required 
to interface

Adafruit invests time and resources providing this open source code, 
please support Adafruit and open-source hardware by purchasing 
products from Adafruit!

Written by Limor Fried/Ladyada for Adafruit Industries.  
BSD license, all text above must be included in any redistribution
**********************************************************/

#include <Wire.h>
#include "Adafruit_MPR121.h"

// You can have up to 4 on one i2c bus but one is enough for testing!
Adafruit_MPR121 cap = Adafruit_MPR121();

// Keeps track of the last pins touched
// so we know when buttons are 'released'
uint16_t lasttouched = 0;
uint16_t currtouched = 0;

// Serial Communication to Processing
// number of analog pins to read
#define NUMPINS 4

// read at most 10 times a second
#define READPERIOD 100

// a header for outgoing serial messages
#define MSGHEADER 0xAB

byte serialMsg[3];
int whichPin;
unsigned long lastReadWrite;

void setup() {
  while (!Serial);        // needed to keep leonardo/micro from starting too fast!

  Serial.begin(57600);
  //Serial.println("Adafruit MPR121 Capacitive Touch sensor test"); 
  
  // Default address is 0x5A, if tied to 3.3V its 0x5B
  // If tied to SDA its 0x5C and if SCL then 0x5D
  if (!cap.begin(0x5A)) {
    //Serial.println("MPR121 not found, check wiring?");
    while (1);
  }
  //Serial.println("MPR121 found!");
  serialMsg[0] = serialMsg[1] = serialMsg[2] = 0x00;
  whichPin = 0;
  lastReadWrite = millis();
}

void loop() {
  
  // Überprüfung Interval
  if(millis()-lastReadWrite > READPERIOD){
    
    // Sende Sensor Daten von 3 inputs an processing (bis zu 12 sind möglich)
    short readValue;
    for (uint8_t i=0; i<3; i++) {
      
      readValue = cap.filteredData(i);
      
      serialMsg[0] = (MSGHEADER&0xFF);
      serialMsg[1] = ((whichPin<<4)&0xF0) | ((readValue>>8)&0x0F);
      serialMsg[2] = (readValue&0xFF);

      Serial.write(serialMsg[0]);
      Serial.write(serialMsg[1]);
      Serial.write(serialMsg[2]);
      
      whichPin = whichPin +1;
    }
    Serial.flush();
    whichPin = 0;
    lastReadWrite = millis();
    /*Serial.println();
    Serial.print("Base: ");
    for (uint8_t i=0; i<12; i++) {
      Serial.print(cap.baselineData(i)); Serial.print("\t");
    }
    Serial.println();*/
    
    
  } // End of if millis Interval action
  // put a delay so it isn't overwhelming
  //delay(100);
}
